@@ -27,7 +27,7 @@ roc_data = function(prediction) {
   }
 
   data.table(
-    scores = prediction$prob[, 1L],
+    scores = prediction$prob[, 1L, drop = TRUE],
     labels = prediction$truth
   )
 }
@@ -42,7 +42,7 @@ as_precrec.PredictionClassif = function(object) { # nolint
     scores = data$scores,
     labels = data$labels,
     dsids = 1L,
-    posclass = levels(data$labels)[1L]
+    posclass = levels(object$truth)[1L]
   )
 }
 
@@ -53,10 +53,12 @@ as_precrec.ResampleResult = function(object) { # nolint
   require_namespaces("precrec")
   predictions = object$predictions()
   data = transpose_list(map(predictions, roc_data))
+
   precrec::mmdata(
-    scores = data$scores, labels = data$labels,
+    scores = data$scores,
+    labels = data$labels,
     dsids = seq_along(predictions),
-    posclass = levels(data$labels)[1L]
+    posclass = object$task$positive
   )
 }
 
@@ -82,10 +84,10 @@ as_precrec.BenchmarkResult = function(object) { # nolint
   lrns = unique(scores$learner_id)
   iters = unique(scores$iteration)
   precrec::mmdata(
-    data$scores,
-    data$labels,
+    scores = data$scores,
+    labels = data$labels,
     dsids = iters,
     modnames = lrns,
-    posclass = levels(data$labels)[1L]
+    posclass = object$tasks$task[[1L]]$positive
   )
 }
